@@ -1,7 +1,7 @@
 #include "networkaccessmanagerfactory.h"
 #include "xbmc/xbmcconnection.h"
 
-QNetworkAccessManager* NetworkAccessManagerFactory::create(QObject *parent)
+QNetworkAccessManager* NetworkAccessManagerFactory::create(QObject *)
 {
     return XbmcConnection::nam();
 }
