@@ -1,3 +1,21 @@
+/*****************************************************************************
+ * Copyright: 2011 Michael Zanetti <mzanetti@kde.org>                        *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 3 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ ****************************************************************************/
+
 #include "episodes.h"
 #include "xbmcconnection.h"
 #include "xbmc.h"
@@ -6,7 +24,7 @@
 #include "videoplaylistitem.h"
 
 Episodes::Episodes(int tvshowid, int seasonid, const QString &seasonString, XbmcModel *parent):
-    XbmcModel(parent),
+    XbmcLibrary(parent),
     m_tvshowid(tvshowid),
     m_seasonid(seasonid),
     m_seasonString(seasonString)
@@ -18,10 +36,9 @@ Episodes::Episodes(int tvshowid, int seasonid, const QString &seasonString, Xbmc
     if(tvshowid != -1) {
       params.insert("season", seasonid);
     }
-    QVariantList fields;
-    fields.append("showtitle");
-//    fields.append("season");
-    params.insert("fields", fields);
+    QVariantList properties;
+    properties.append("showtitle");
+    params.insert("properties", properties);
 
     QVariantMap sort;
     sort.insert("method", "label");
@@ -85,7 +102,7 @@ void Episodes::playItem(int index)
     VideoPlaylistItem item;
     item.setEpisodeId(m_list.at(index)->data(RoleEpisodeId).toInt());
     Xbmc::instance()->videoPlayer()->playlist()->addItems(item);
-    Xbmc::instance()->videoPlayer()->playlist()->playItem(0);
+    Xbmc::instance()->videoPlayer()->playItem(0);
 }
 
 void Episodes::addToPlaylist(int row)
