@@ -1,3 +1,21 @@
+/*****************************************************************************
+ * Copyright: 2011 Michael Zanetti <mzanetti@kde.org>                        *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 3 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ ****************************************************************************/
+
 #include "seasons.h"
 #include "episodes.h"
 #include "xbmcconnection.h"
@@ -7,17 +25,17 @@
 #include "videoplaylistitem.h"
 
 Seasons::Seasons(int tvshowid, XbmcModel *parent):
-    XbmcModel(parent),
+    XbmcLibrary(parent),
     m_tvshowid(tvshowid)
 {
     QVariantMap params;
     if(tvshowid != -1) {
       params.insert("tvshowid", tvshowid);
     }
-    QVariantList fields;
-    fields.append("showtitle");
-    fields.append("season");
-    params.insert("fields", fields);
+    QVariantList properties;
+    properties.append("showtitle");
+    properties.append("season");
+    params.insert("properties", properties);
 
     QVariantMap sort;
     sort.insert("method", "label");
