@@ -1,11 +1,29 @@
+/*****************************************************************************
+ * Copyright: 2011 Michael Zanetti <mzanetti@kde.org>                        *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 3 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ ****************************************************************************/
+
 #include "videoplaylistitem.h"
 
 VideoPlaylistItem::VideoPlaylistItem(int movieId, int musicVideoId, int episodeId):
     m_movieId(movieId),
     m_musicVideoId(musicVideoId),
-    m_episodeId(episodeId),
     m_tvShowId(-1),
-    m_seasonId(-1)
+    m_seasonId(-1),
+    m_episodeId(episodeId)
 {
 }
 
@@ -65,18 +83,23 @@ QVariantMap VideoPlaylistItem::toMap() const
     if(m_movieId != -1) {
         map.insert("movieid", m_movieId);
     }
+
     if(m_musicVideoId != -1) {
         map.insert("musicvideoid", m_musicVideoId);
     }
+
     if(m_tvShowId != -1) {
         map.insert("tvshowid", m_tvShowId);
     }
+
     if(m_seasonId != -1) {
         map.insert("seasonid", m_seasonId);
     }
+
     if(m_episodeId != -1) {
         map.insert("episodeid", m_episodeId);
     }
+
     return map;
 }
 
