@@ -225,6 +225,7 @@ Player *Xbmc::activePlayer()
 
 void Xbmc::parseAnnouncement(const QVariantMap &map)
 {
+    Q_UNUSED(map)
 }
 
 void Xbmc::responseReceived(int id, const QVariantMap &response)
@@ -339,7 +340,7 @@ int Xbmc::volume()
 
 void Xbmc::quit()
 {
-    XbmcConnection::sendCommand("XBMC.Quit");
+    XbmcConnection::sendCommand("Application.Quit");
 }
 
 void Xbmc::dimVolumeTo(int newVolume)
