@@ -34,18 +34,20 @@ namespace XbmcConnection
 class Command
 {
 public:
-    Command(int id, const QString &command, const QVariant &params):
-        m_id(id), m_command(command), m_params(params) {}
+    Command(int id = -1, const QString &command = QString(), const QVariant &params = QVariant(), const QString &raw = QString()):
+        m_id(id), m_command(command), m_params(params), m_raw(raw) {}
 
     int id() {return m_id;}
     QString command() {return m_command;}
     QVariant params() {return m_params;}
+    QString raw() {return m_raw; }
 
 private:
 
     int m_id;
     QString m_command;
     QVariant m_params;
+    QString m_raw;
 };
 
 class XbmcConnectionPrivate : public QObject
@@ -54,7 +56,7 @@ class XbmcConnectionPrivate : public QObject
 public:
     explicit XbmcConnectionPrivate(QObject *parent = 0);
 
-    void connect(const QString &hostname, int port);
+    void connect(const QString &hostname, int port, const QString &username, const QString &password);
 
     int sendCommand(const QString &command, const QVariant &parms = QVariant());
 
@@ -65,6 +67,8 @@ public:
     bool connected();
     QString connectionError();
 
+    QNetworkAccessManager *nam();
+
 private slots:
     void readData();
     void clearPending();
@@ -73,6 +77,7 @@ private slots:
     void slotDisconnected();
 
     void replyReceived();
+    void authenticationRequired(QNetworkReply *reply, QAuthenticator *authenticator);
 private:
     QTcpSocket *m_socket;
     int m_commandId;
@@ -80,7 +85,7 @@ private:
     int m_versionRequestId;
 
     QList<Command> m_commandQueue;
-    int m_currentPendingId;
+    Command m_currentPendingCommand;
     QTimer m_timeoutTimer;
 
     void sendNextCommand();
@@ -88,8 +93,11 @@ private:
 
     QString m_hostName;
     int m_port;
+    QString m_username;
+    QString m_password;
 
     QNetworkAccessManager *m_network;
+    QNetworkReply *m_lastAuthRequest;
     bool m_connected;
     QString m_connectionError;
 
